@@ -10,6 +10,25 @@ import fmdt.core
 import fmdt.utils
 import fmdt.args
 
+def help():
+    s = """    fmdt.api contains a Python wrapper for the `fmdt-detect` and `fmdt-visu` 
+    executables.
+    
+    fmdt.api contains the public-facing functions (also aliased under fmdt.*):
+        fmdt[.api].count
+        fmdt[.api].detect
+        fmdt[.api].visu
+        fmdt[.api].detect_directory
+
+    fmdt.api.count counts the number of celestial objects specified by the parameters
+    fmdt.api.detect calls `fmdt-detect` with the given arguments
+    fmdt.api.visu calls `fmdt-visu`
+    fmdt.api.detect_directory
+        
+        
+        
+"""
+
 def count(
         trk_bb_path: str,
         stars: bool = False,
@@ -65,8 +84,8 @@ def detect(
         trk_all: bool | None = None,
         trk_bb_path: str | None = None,
         trk_mag_path: str | None = None,
+        trk_out_path: str | None = None,
         log_path: str | None = None,
-        out_track_file: str | None = None,
         log: bool = False
     ) -> fmdt.args.Args:
     """Wrapper to executable fmdt-detect.
@@ -76,57 +95,66 @@ def detect(
     """
 
     # Wrap up all of the arguments into a dictionary
-    detect_args = fmdt.args.detect_args(vid_in_path, vid_in_start, vid_in_stop, 
+    detect_args, visu_args = fmdt.args.detect_args(vid_in_path, vid_in_start, vid_in_stop, 
         vid_in_skip, vid_in_buff, vid_in_loop, vid_in_threads, light_min, light_max, 
         ccl_fra_path, ccl_fra_id, mrp_s_min, mrp_s_max, knn_k, knn_d, knn_s, trk_ext_d,
         trk_ext_o, trk_angle, trk_star_min, trk_meteor_min, trk_meteor_max, trk_ddev, 
-        trk_all, trk_bb_path, trk_mag_path, log_path, out_track_file, log
+        trk_all, trk_bb_path, trk_mag_path, log_path, trk_out_path, log
     )
 
     # Spit out the commandline
     args = fmdt.args.handle_detect_args(**detect_args)
 
-    if out_track_file is None:
+    if trk_out_path is None:
         if log:
             print(f"Executing cmd: {' '.join(args)}")
         subprocess.run(args)
     else:
-        with open(out_track_file, 'w') as outfile:
+        with open(trk_out_path, 'w') as outfile:
             if log:
                 print(f"Executing cmd: {' '.join(args)}")
             subprocess.run(args, stdout=outfile)
     
     # And return the Args object that keeps track of the detect call
-    if not out_track_file is None:
-        out = fmdt.args.Args(fmdt.core.extract_all_information(out_track_file), detect_args)
+    if not trk_out_path is None:
+        out = fmdt.args.Args(fmdt.core.extract_all_information(trk_out_path), detect_args, visu_args)
     else:
-        out = fmdt.args.Args(detect_args=detect_args)
+        out = fmdt.args.Args(detect_args=detect_args, visu_args=visu_args)
     
     return out
 
 
 def visu(
-        in_video: str,
-        in_track_file: str,
-        in_bb_file: str,
-        out_visu_file: str | None = None,
-        show_id: bool = False
-    ) -> None:
+        vid_in_path: str = None,
+        vid_in_start: int = None,
+        vid_in_stop: int = None,
+        vid_in_threads: int = None,
+        trk_path: str = None,
+        trk_bb_path: str = None,
+        trk_id: bool = None,
+        trk_nat_num: bool = None,
+        trk_only_meteor: bool = None,
+        gt_path: str = None,
+        vid_out_path: str = None
+    ) -> fmdt.args.Args:
 
-    fmdt_visu_exe = shutil.which("fmdt-visu")
-    fmdt_visu_found = not fmdt_visu_exe is None
-    assert fmdt_visu_found, "fmdt-visu executable not found"   
+    visu_args = fmdt.args.visu_args(vid_in_path, 
+                                    vid_in_start,
+                                    vid_in_stop,
+                                    vid_in_threads,
+                                    trk_path,
+                                    trk_bb_path,
+                                    trk_id,
+                                    trk_nat_num,
+                                    trk_only_meteor,
+                                    gt_path,
+                                    vid_out_path)
 
-    args = [fmdt_visu_exe, "--in-video", in_video, "--in-tracks", in_track_file, "--in-bb", in_bb_file] 
-
-    if not out_visu_file is None:
-        args.extend(["--out-video", out_visu_file])
-
-    if show_id:
-        args.append("--show-id")
+    args = fmdt.args.handle_visu_args(**visu_args)
 
     subprocess.run(args)
 
+    return fmdt.args.Args(visu_args=visu_args)
 
 def detect_directory(dir_name: str, args: fmdt.args.Args, log=False):
 
@@ -134,13 +162,15 @@ def detect_directory(dir_name: str, args: fmdt.args.Args, log=False):
     is_video_fn = lambda v: v[-3:] == "mp4" or v[-3:] == "avi"
     videos = [e for e in entries if is_video_fn(e)]
 
+    assert len(videos) > 0, "Directory is empty, call to fmdt.detect_directory failed"
+
     # Now let's call fmdt detect one time for each video
     failing_cmds = []
     i = 0
     for v in videos:
-        # res = fmdt.detect(directory + "/" + v, light_min=150, light_max=245, trk_all=True, log=False, out_track_file="tracks.txt")
+        # res = fmdt.detect(directory + "/" + v, light_min=150, light_max=245, trk_all=True, log=False, trk_out_path="tracks.txt")
         # a = fmdt.args.video_input(directory + "/" + v)
-        # a.detect_args["out_track_file"] = "tracks.txt"
+        # a.detect_args["trk_out_path"] = "tracks.txt"
 
         # if i > 10:
         #     break
@@ -156,4 +186,6 @@ def detect_directory(dir_name: str, args: fmdt.args.Args, log=False):
         i = i + 1
 
     for c in failing_cmds:
-        print(c)
\ No newline at end of file
+        print(c)
+
+# Launch multiple processes of 
\ No newline at end of file
